PCB Environment: ui::NavGrid Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
ui::NavGrid Class Reference

## Public Member Functions
| NavGrid (const PCBoard &)
void | update ()
void | setLineSize (float s)
void | setColor (Color)
void | draw (const Camera &)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/NavGrid.hpp